from __future__ import unicode_literals, print_function
import os
import pytest


def test_ping(salt):
    #print(os.environ)
    assert salt('test.ping') is True


@pytest.mark.skipif('freebsd' in os.environ.get('KITCHEN_INSTANCE'), reason='Skip on freebsd images')
@pytest.mark.skipif('windows' in os.environ.get('KITCHEN_INSTANCE'), reason='git not installed on windows')
def test_git_depends(salt):
    formulas = {'linux', 'git'}
    dirs = salt('cp.list_master_dirs')
    assert all([formula in dirs for formula in formulas])


@pytest.mark.skipif('centos' in os.environ.get('KITCHEN_INSTANCE'), reason='Skip on centos images')
@pytest.mark.skipif('freebsd' in os.environ.get('KITCHEN_INSTANCE'), reason='Skip on freebsd images')
@pytest.mark.skipif('windows' in os.environ.get('KITCHEN_INSTANCE'), reason='APT not supported on windows')
def test_apt_depends(salt):
    formulas = {'nginx',}
    dirs = salt('cp.list_master_dirs')
    assert all([formula in dirs for formula in formulas])


@pytest.mark.skipif('windows' in os.environ.get('KITCHEN_INSTANCE'), reason='git not installed on windows')
def test_postfix_depends(salt):
    formulas = {'postfix',}
    dirs = salt('cp.list_master_dirs')
    assert all([formula in dirs for formula in formulas])


@pytest.mark.xfail
@pytest.mark.skipif('windows' in os.environ.get('KITCHEN_INSTANCE'), reason='spm not supported on windows')
def test_spm_depends(salt):
    formulas = {'hubblestack_nova'}
    dirs = salt('cp.list_master_dirs')
    print(dirs)
    assert all([formula in dirs for formula in formulas])


def test_path_depends(salt):
    formulas = set(['foo',])
    dirs = salt('cp.list_master_dirs')
    print(dirs)
    assert all([formula in dirs for formula in formulas])


def test_cache_command_ran(salt):
    files = salt('cp.list_master')
    print(files)
    assert 'cache_commands_test' in files


@pytest.mark.skipif('windows' not in os.environ.get('KITCHEN_INSTANCE'), reason='Skip windows specific test')
def test_path_line_endings(salt):
    res = salt('cp.get_file_str', 'salt://top.sls')
    assert res == '---\r\nbase:\r\n  "*":\r\n  - foo\r\n'



import os
import pytest


@pytest.mark.skipif('windows' in os.environ.get('KITCHEN_INSTANCE'), reason='dotfiles are ignored on windows')
def test_hidden_dirs(salt):
    expected = ('tests/.hidden',)
    ignored = ('tests/.filter_hidden',)
    dirs = salt('cp.list_master_dirs')
    assert all([exp in dirs for exp in expected])
    assert not any([exp in dirs for exp in ignored])


@pytest.mark.skipif('windows' in os.environ.get('KITCHEN_INSTANCE'), reason='dotfiles are ignored on windows')
def test_hidden_sls(salt):
    expected = ('tests/.hidden/test.sls',)
    ignored = ('tests/.filter_hidden/test.sls',)
    dirs = salt('cp.list_master')
    assert all([exp in dirs for exp in expected])
    assert not any([exp in dirs for exp in ignored])



import pytest
import os

@pytest.mark.skipif('windows' in os.environ.get('KITCHEN_INSTANCE'), reason='Skip on freebsd images')
@pytest.mark.parametrize("pkgname", [
    "git",
])
def test_pkg(host, pkgname):
    pkg = host.package(pkgname)
    assert pkg.is_installed is True



import os
import pytest


@pytest.mark.skipif('freebsd' in os.environ.get('KITCHEN_INSTANCE'), reason='Skip on freebsd images')
@pytest.mark.skipif('windows' in os.environ.get('KITCHEN_INSTANCE'), reason='Skip on windows')
def test_gpg_pillar(salt):
    assert salt('pillar.get', 'gpg:test') == 'supersecret'



import os
import pytest


@pytest.mark.skipif('freebsd' in os.environ.get('KITCHEN_INSTANCE'), reason='Skip on freebsd images')
@pytest.mark.skipif('windows' in os.environ.get('KITCHEN_INSTANCE'), reason='Skip on windows images')
def test_jdoe(host):
    jdoe = host.user('jdoe')
    assert jdoe.name == 'jdoe'
    assert jdoe.home == '/home/jdoe'



import functools
import os
import pytest
import testinfra

if os.environ.get('KITCHEN_USERNAME') == 'vagrant':
    if 'windows' in os.environ.get('KITCHEN_INSTANCE'):
        test_host = testinfra.get_host('winrm://{KITCHEN_USERNAME}:{KITCHEN_PASSWORD}@{KITCHEN_HOSTNAME}:{KITCHEN_PORT}'.format(**os.environ), no_ssl=True)
    else:
        test_host = testinfra.get_host('paramiko://{KITCHEN_USERNAME}@{KITCHEN_HOSTNAME}:{KITCHEN_PORT}'.format(**os.environ),
                                       ssh_identity_file=os.environ.get('KITCHEN_SSH_KEY'))
else:
    test_host = testinfra.get_host('docker://{KITCHEN_USERNAME}@{KITCHEN_CONTAINER_ID}'.format(**os.environ))

@pytest.fixture
def host():
    return test_host

@pytest.fixture
def salt():
    if 'windows' in os.environ.get('KITCHEN_INSTANCE'):
        tmpconf = r'c:\Users\vagrant\AppData\Local\Temp\kitchen\etc\salt'
    else:
        test_host.run('sudo chown -R {0} /tmp/kitchen'.format(os.environ.get('KITCHEN_USERNAME')))
        tmpconf = '/tmp/kitchen/etc/salt'
    return functools.partial(test_host.salt, config=tmpconf)
